@@ -15,7 +15,7 @@ from pathlib import Path
 
 settings = {
     'n': 80,  # The number of cues along x.
-    'x_max': 3,  # The maximum x-value magnitude cues.
+    'x_max': 2,  # The maximum x-value magnitude of cues.
     'use_error': True,
     'use_error_factor': 0.01,
 }
@@ -99,8 +99,11 @@ class Context():
         plt.figure()
         plt.scatter(self.xs, self.ps)
         plt.xlabel('Change in fitness')
-        plt.ylabel('Occurence likelihood')
+        plt.ylabel('Outcome frequency')
         plt.grid(visible=True, axis='y')
+        ylim = list(plt.ylim())
+        ylim[0] = 0
+        plt.ylim(ylim)
         plt.tight_layout()
 
 
@@ -940,7 +943,7 @@ class Population():
                   i=i, folder=folder, fmt=fmt)
         self.plot(var='behaviour_dist', label='Behaviour factor',
                   i=i, folder=folder, fmt=fmt)
-        self.plot(var='occurances', label='Occurence likelihood',
+        self.plot(var='occurances', label='Outcome frequency',
                   i=i, folder=folder, fmt=fmt)
         self.plot(var='weighted_error', label='Weighted error',
                   i=i, folder=folder, fmt=fmt)
