@@ -5,11 +5,21 @@ Created on Sun May  8 19:58:32 2022
 @author: Reuben
 """
 
+import matplotlib
 import matplotlib.pyplot as plt
 from pathlib import Path
 
 from . import amm
 
+def set_font_size(size=14):
+    """ Convenience function to set font size in figures 
+    
+    Call prior to run_amm.
+    
+    """
+    font = {'size': size}
+    matplotlib.rc('font', **font)    
+
 
 class AMM_Demo():
     """ Standard demonstration of the Adaptive Motivation Model of wellbeing 
@@ -73,14 +83,20 @@ class AMM_Demo():
     def hedonic_adaptation_up(self, pop, **kwargs):
         return self.hedonic_adaptation_down(pop, ind=60, **kwargs)
     
-    def run_all(self, folder=None, pop=None):
+    def run_all(self, folder=None, pop=None, fmt='svg'):
         pop = self.run() if pop is None else pop
-        # pop.plot_all(folder=folder, i=0, fmt='svg')
-        pop.plot_all(folder=folder, i=-1, fmt='svg')
-        # pop.plot_all(folder=folder, i=0, fmt='svg')
+        # pop.plot_all(folder=folder, i=0, fmt=fmt)
+        pop.plot_all(folder=folder, i=-1, fmt=fmt)
         pop_ha_down = self.hedonic_adaptation_down(pop)
         pop_ha_up = self.hedonic_adaptation_up(pop)
-        y = 9
+        self.plot_adaptation(pop_ha_down, pop_ha_up, y=8, folder=folder,
+                             fmt=fmt)
+        pop.lh.contexts[0]['context'].plot()
+        plt.savefig(Path(folder) / ('initial_cue_dist.' + fmt), dpi=300,
+                    format=fmt)
+        return pop
+        
+    def plot_adaptation(self, pop_ha_down, pop_ha_up, y, folder=None, fmt='svg'):
         fig = pop_ha_down.pop[y].plot_wb_history(xlim=(195, 270),
                                          label='Avoidance situation',
                                          linestyle='--')
@@ -90,12 +106,13 @@ class AMM_Demo():
         plt.axhline(pop_ha_up.pop[y].subj_wb_history()[1][-1], linestyle=':',
                     label='Baseline')
         plt.legend()
-        plt.savefig(Path(folder) / 'hedonic_adaptation.svg', dpi=300, format='svg')
-        return pop
+        if folder is not None:
+            plt.savefig(Path(folder) / ('hedonic_adaptation.' + fmt), dpi=300,
+                        format=fmt)
 
 
-def run_amm(folder=None):
+def run_amm(folder=None, fmt='svg'):
     s = AMM_Demo()
-    return s.run_all(folder=folder)
+    return s.run_all(folder=folder, fmt=fmt)
     
 
